searchData={"items":[{"type":"module","title":"TelemetryMetricsCloudwatch","doc":"This is a [Amazon CloudWatch](https://aws.amazon.com/cloudwatch/) Reporter for\n[`Telemetry.Metrics`](https://github.com/beam-telemetry/telemetry_metrics) definitions.\n\nProvide a list of metric definitions to the `init/2` function. It's recommended to\nrun TelemetryMetricsCloudwatch under a supervision tree, usually under Application.\n\n    def start(_type, _args) do\n      # List all child processes to be supervised\n      children = [\n        {TelemetryMetricsCloudwatch, [metrics: metrics()]}\n      ...\n      ]\n\n      opts = [strategy: :one_for_one, name: ExampleApp.Supervisor]\n      Supervisor.start_link(children, opts)\n    end\n\n    defp metrics do\n      [\n        counter(\"http.request.count\"),\n        last_value(\"vm.memory.total\", unit: :byte),\n        last_value(\"vm.total_run_queue_lengths.total\")\n      ]\n    end\n\nYou can also provide options for the namespace used in CloudWatch (by default, \"Telemetry\")\nand the minimum frequency (in milliseconds) with which data will be posted (see section\nbelow for posting rules).  For instance:\n\n    ...\n    children = [\n       {TelemetryMetricsCloudwatch, metrics: metrics(), namespace: \"Backend\", push_interval: 30_000}\n    ]\n    ...","ref":"TelemetryMetricsCloudwatch.html"},{"type":"module","title":"Telemetry.Metrics Types Supported - TelemetryMetricsCloudwatch","doc":"`TelemetryMetricsCloudwatch` supports 4 of the [Metrics](https://hexdocs.pm/telemetry_metrics/Telemetry.Metrics.html#module-metrics):\n\n  * [Counter](https://hexdocs.pm/telemetry_metrics/Telemetry.Metrics.html#counter/2):\n    Counter metric keeps track of the total number of specific events emitted.\n  * [LastValue](https://hexdocs.pm/telemetry_metrics/Telemetry.Metrics.html#last_value/2):\n    Last value keeps track of the selected measurement found in the most recent event.\n  * [Summary](https://hexdocs.pm/telemetry_metrics/Telemetry.Metrics.html#summary/2): Summary\n    aggregates measurement's values into statistics, e.g. minimum and maximum, mean, or percentiles.\n    This sends every measurement to CloudWatch.\n  * [Sum](https://hexdocs.pm/telemetry_metrics/Telemetry.Metrics.html#sum/2): Sum metric keeps track\n    of the sum of selected measurement's values carried by specific events.  If you are using Summary\n    for a metric already, then CloudWatch can calculate a Sum using that Summary metric.  If you\n    only need a Sum (and no other summary metrics) then use this Sum metric instead.\n\nThese metrics are sent to CloudWatch based on the rules described below.","ref":"TelemetryMetricsCloudwatch.html#module-telemetry-metrics-types-supported"},{"type":"module","title":"When Data is Sent - TelemetryMetricsCloudwatch","doc":"Cloudwatch has [certain constraints](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/publishingMetrics.html)\non the number of metrics that can be sent up at any given time.  `TelemetryMetricsCloudwatch`\nwill send accumulated metric data at least every minute (configurable by the `:push_interval`\noption) or when the data cache has reached the maximum size that CloudWatch will accept.","ref":"TelemetryMetricsCloudwatch.html#module-when-data-is-sent"},{"type":"module","title":"Event Sampling - TelemetryMetricsCloudwatch","doc":"You can optionally send only a portion of reported events to CloudWatch via the `:sample_rate` option.  This\nparameter should contain a value between 0.0 and 1.0 (inclusive), and represents the proportion of events that\nwill be reported.  For instance, a sample rate value of 0.0 will ensure no events are sent, whereas a sample\nrate value of 1.0 will ensure all events are sent. A sample rate of 0.25 will result in roughly a quarter of\nall events being sent.\n\n*Note:* Using a sampling rate of less than 1.0 will result in incorrect values for the \"Sum\" and \"Counter\" metric\ntypes (and some of the values like min/max for the \"Summary\" metric type) due to the under-reporting of events.\nYou should only use a sampling rate of less than 1.0 if you have a guaranteed high rate of events and only care\nabout summary statistics like averages and percentiles.","ref":"TelemetryMetricsCloudwatch.html#module-event-sampling"},{"type":"module","title":"Units - TelemetryMetricsCloudwatch","doc":"In order to report metrics in the CloudWatch UI, they must be one of the following values:\n\n  * Time units: `:second`, `:microsecond`, `:millisecond`\n  * Byte sizes: `:byte`, `:kilobyte`, `:megabyte`, `:gigabyte`, `:terabyte`\n  * Bit sizes: `:bit`, `:kilobit`, `:megabit`, `:gigabit`, `:terabit`\n\nFor `Telemetry.Metrics.Counter`s, the unit will always be `:count`.  Otherwise, the unit will be treated as `nil`.","ref":"TelemetryMetricsCloudwatch.html#module-units"},{"type":"module","title":"Notes on AWS - TelemetryMetricsCloudwatch","doc":"[`ExAws`](https://hexdocs.pm/ex_aws/ExAws.html) is the library used to send metrics to CloudWatch.  Make sure your\n[keys are configured](https://hexdocs.pm/ex_aws/ExAws.html#module-aws-key-configuration) and that they have the\n[correct permissions](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/permissions-reference-cw.html) of `cloudwatch:PutMetricData`.\n\nUp to 10 tags are sent up to AWS as dimensions for a given metric.  Every metric name will have a suffix added based on\nthe metric type (CloudWatch doesn't allow different units / measurements with the same name).  So, for instance,\nif your metrics are:\n\n    summary(\"my_app.repo.query.total_time\", unit: {:nanosecond, :millisecond})\n    counter(\"my_app.repo.query.total_time\")\n\nThen the metric names in CloudWatch will be:\n\n  * `my_app.repo.query.total_time.summary` (with all data points recorded)\n  * `my_app.repo.query.total_time.count` (with the number of queries recorded)","ref":"TelemetryMetricsCloudwatch.html#module-notes-on-aws"},{"type":"function","title":"TelemetryMetricsCloudwatch.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"TelemetryMetricsCloudwatch.html#child_spec/1"},{"type":"function","title":"TelemetryMetricsCloudwatch.handle_telemetry_event/4","doc":"","ref":"TelemetryMetricsCloudwatch.html#handle_telemetry_event/4"},{"type":"function","title":"TelemetryMetricsCloudwatch.start_link/1","doc":"Start the `TelemetryMetricsCloudwatch` `GenServer`.\n\nAvailable options:\n* `:name` - name of the reporter instance.\n* `:metrics` - a list of `Telemetry.Metrics` to track.\n* `:namespace` - Namespace to use in CloudWatch\n* `:push_interval` - The minimum interval that metrics are guaranteed to be pushed to cloudwatch (in milliseconds)\n* `:sample_rate` - Sampling factor to apply to metrics. 0.0 will deny all events, 1.0 will queue all events.","ref":"TelemetryMetricsCloudwatch.html#start_link/1"},{"type":"module","title":"TelemetryMetricsCloudwatch.Cache","doc":"State for `GenServer`.  Nothing here should be called directly outside of the\n`TelemetryMetricsCloudwatch` module.","ref":"TelemetryMetricsCloudwatch.Cache.html"},{"type":"function","title":"TelemetryMetricsCloudwatch.Cache.max_values_per_metric/1","doc":"","ref":"TelemetryMetricsCloudwatch.Cache.html#max_values_per_metric/1"},{"type":"function","title":"TelemetryMetricsCloudwatch.Cache.metric_count/1","doc":"","ref":"TelemetryMetricsCloudwatch.Cache.html#metric_count/1"},{"type":"function","title":"TelemetryMetricsCloudwatch.Cache.pop_metrics/1","doc":"","ref":"TelemetryMetricsCloudwatch.Cache.html#pop_metrics/1"},{"type":"function","title":"TelemetryMetricsCloudwatch.Cache.push_measurement/4","doc":"","ref":"TelemetryMetricsCloudwatch.Cache.html#push_measurement/4"},{"type":"function","title":"TelemetryMetricsCloudwatch.Cache.validate_metrics/1","doc":"","ref":"TelemetryMetricsCloudwatch.Cache.html#validate_metrics/1"},{"type":"module","title":"TelemetryMetricsCloudwatch.Cloudwatch","doc":"Functions for interacting with [Amazon CloudWatch](https://aws.amazon.com/cloudwatch/).","ref":"TelemetryMetricsCloudwatch.Cloudwatch.html"},{"type":"function","title":"TelemetryMetricsCloudwatch.Cloudwatch.send_metrics/2","doc":"","ref":"TelemetryMetricsCloudwatch.Cloudwatch.html#send_metrics/2"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}